@@ -16,7 +16,7 @@
 """Test class for iBoot PDU driver module."""
 
 import types
-
+from unittest import mock
 
 from ironic.common import exception as ironic_exception
 from ironic.common import states
@@ -24,7 +24,6 @@ from ironic.conductor import task_manager
 from ironic.drivers.modules import fake
 from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.objects import utils as obj_utils
-import mock
 
 from ironic_staging_drivers.iboot import power as iboot_power
 
